@@ -39,7 +39,7 @@ class RollupClient(NamespacedClient):
         """
         Deletes an existing rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/rollup-delete-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.9/rollup-delete-job.html>`_
 
         :param id: The ID of the job to delete
         """
@@ -75,7 +75,7 @@ class RollupClient(NamespacedClient):
         """
         Retrieves the configuration, stats, and status of rollup jobs.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/rollup-get-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.9/rollup-get-job.html>`_
 
         :param id: The ID of the job(s) to fetch. Accepts glob patterns, or left blank
             for all jobs
@@ -114,7 +114,7 @@ class RollupClient(NamespacedClient):
         Returns the capabilities of any rollup jobs that have been configured for a specific
         index or index pattern.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/rollup-get-rollup-caps.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.9/rollup-get-rollup-caps.html>`_
 
         :param id: The ID of the index to check rollup capabilities on, or left blank
             for all jobs
@@ -153,7 +153,7 @@ class RollupClient(NamespacedClient):
         Returns the rollup capabilities of all jobs inside of a rollup index (e.g. the
         index where rollup data is stored).
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/rollup-get-rollup-index-caps.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.9/rollup-get-rollup-index-caps.html>`_
 
         :param index: The rollup index or index pattern to obtain rollup capabilities
             from.
@@ -205,7 +205,7 @@ class RollupClient(NamespacedClient):
         """
         Creates a rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/rollup-put-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.9/rollup-put-job.html>`_
 
         :param id: Identifier for the rollup job. This can be any alphanumeric string
             and uniquely identifies the data that is associated with the rollup job.
@@ -291,53 +291,6 @@ class RollupClient(NamespacedClient):
             "PUT", __path, params=__query, headers=__headers, body=__body
         )
 
-    @_rewrite_parameters(
-        body_name="config",
-    )
-    async def rollup(
-        self,
-        *,
-        index: str,
-        rollup_index: str,
-        config: t.Any,
-        error_trace: t.Optional[bool] = None,
-        filter_path: t.Optional[
-            t.Union[str, t.Union[t.List[str], t.Tuple[str, ...]]]
-        ] = None,
-        human: t.Optional[bool] = None,
-        pretty: t.Optional[bool] = None,
-    ) -> ObjectApiResponse[t.Any]:
-        """
-        Rollup an index
-
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/xpack-rollup.html>`_
-
-        :param index: The index to roll up
-        :param rollup_index: The name of the rollup index to create
-        :param config:
-        """
-        if index in SKIP_IN_PATH:
-            raise ValueError("Empty value passed for parameter 'index'")
-        if rollup_index in SKIP_IN_PATH:
-            raise ValueError("Empty value passed for parameter 'rollup_index'")
-        if config is None:
-            raise ValueError("Empty value passed for parameter 'config'")
-        __path = f"/{_quote(index)}/_rollup/{_quote(rollup_index)}"
-        __query: t.Dict[str, t.Any] = {}
-        if error_trace is not None:
-            __query["error_trace"] = error_trace
-        if filter_path is not None:
-            __query["filter_path"] = filter_path
-        if human is not None:
-            __query["human"] = human
-        if pretty is not None:
-            __query["pretty"] = pretty
-        __body = config
-        __headers = {"accept": "application/json", "content-type": "application/json"}
-        return await self.perform_request(  # type: ignore[return-value]
-            "POST", __path, params=__query, headers=__headers, body=__body
-        )
-
     @_rewrite_parameters(
         body_fields=True,
     )
@@ -361,7 +314,7 @@ class RollupClient(NamespacedClient):
         """
         Enables searching rolled-up data using the standard query DSL.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/rollup-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.9/rollup-search.html>`_
 
         :param index: The indices or index-pattern(s) (containing rollup or regular data)
             that should be searched
@@ -419,7 +372,7 @@ class RollupClient(NamespacedClient):
         """
         Starts an existing, stopped rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/rollup-start-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.9/rollup-start-job.html>`_
 
         :param id: The ID of the job to start
         """
@@ -457,7 +410,7 @@ class RollupClient(NamespacedClient):
         """
         Stops an existing, started rollup job.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.4/rollup-stop-job.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.9/rollup-stop-job.html>`_
 
         :param id: The ID of the job to stop
         :param timeout: Block for (at maximum) the specified duration while waiting for
