@@ -15,34 +15,55 @@
 #  specific language governing permissions and limitations
 #  under the License.
 
-from operator import methodcaller
-import time
-
-from ..exceptions import TransportError
-from ..compat import map, string_types, Queue, Mapping
-
-from .errors import ScanError, BulkIndexError
-
 import logging
+import time
+from operator import methodcaller
+from queue import Queue
+from typing import (
+    Any,
+    Callable,
+    Collection,
+    Dict,
+    Iterable,
+    Iterator,
+    List,
+    Mapping,
+    MutableMapping,
+    Optional,
+    Tuple,
+    Union,
+)
 
+from .. import Elasticsearch
+from ..compat import to_bytes
+from ..exceptions import ApiError, NotFoundError, TransportError
+from ..serializer import Serializer
+from .errors import BulkIndexError, ScanError
 
 logger = logging.getLogger("elasticsearch.helpers")
 
+_TYPE_BULK_ACTION = Union[bytes, str, Dict[str, Any]]
+_TYPE_BULK_ACTION_HEADER = Dict[str, Any]
+_TYPE_BULK_ACTION_BODY = Union[None, bytes, Dict[str, Any]]
+_TYPE_BULK_ACTION_HEADER_AND_BODY = Tuple[
+    _TYPE_BULK_ACTION_HEADER, _TYPE_BULK_ACTION_BODY
+]
 
-def expand_action(data):
+
+def expand_action(data: _TYPE_BULK_ACTION) -> _TYPE_BULK_ACTION_HEADER_AND_BODY:
     """
     From one document or action definition passed in by the user extract the
     action/data lines needed for elasticsearch's
     :meth:`~elasticsearch.Elasticsearch.bulk` api.
     """
     # when given a string, assume user wants to index raw json
-    if isinstance(data, string_types):
-        return '{"index":{}}', data
+    if isinstance(data, (bytes, str)):
+        return {"index": {}}, to_bytes(data, "utf-8")
 
     # make sure we don't alter the action
     data = data.copy()
-    op_type = data.pop("_op_type", "index")
-    action = {op_type: {}}
+    op_type: str = data.pop("_op_type", "index")
+    action: Dict[str, Any] = {op_type: {}}
 
     # If '_source' is a dict use it for source
     # otherwise if op_type == 'update' then
@@ -98,26 +119,49 @@ def expand_action(data):
 
 
 class _ActionChunker:
-    def __init__(self, chunk_size, max_chunk_bytes, serializer):
+    def __init__(
+        self, chunk_size: int, max_chunk_bytes: int, serializer: Serializer
+    ) -> None:
         self.chunk_size = chunk_size
         self.max_chunk_bytes = max_chunk_bytes
         self.serializer = serializer
 
         self.size = 0
         self.action_count = 0
-        self.bulk_actions = []
-        self.bulk_data = []
+        self.bulk_actions: List[bytes] = []
+        self.bulk_data: List[
+            Union[
+                Tuple[_TYPE_BULK_ACTION_HEADER],
+                Tuple[_TYPE_BULK_ACTION_HEADER, _TYPE_BULK_ACTION_BODY],
+            ]
+        ] = []
 
-    def feed(self, action, data):
+    def feed(
+        self, action: _TYPE_BULK_ACTION_HEADER, data: _TYPE_BULK_ACTION_BODY
+    ) -> Optional[
+        Tuple[
+            List[
+                Union[
+                    Tuple[_TYPE_BULK_ACTION_HEADER],
+                    Tuple[_TYPE_BULK_ACTION_HEADER, _TYPE_BULK_ACTION_BODY],
+                ]
+            ],
+            List[bytes],
+        ]
+    ]:
         ret = None
-        raw_data, raw_action = data, action
-        action = self.serializer.dumps(action)
+        raw_action = action
+        raw_data = data
+        action_bytes = to_bytes(self.serializer.dumps(action), "utf-8")
         # +1 to account for the trailing new line character
-        cur_size = len(action.encode("utf-8")) + 1
+        cur_size = len(action_bytes) + 1
 
+        data_bytes: Optional[bytes]
         if data is not None:
-            data = self.serializer.dumps(data)
-            cur_size += len(data.encode("utf-8")) + 1
+            data_bytes = to_bytes(self.serializer.dumps(data), "utf-8")
+            cur_size += len(data_bytes) + 1
+        else:
+            data_bytes = None
 
         # full chunk, send it and start a new one
         if self.bulk_actions and (
@@ -125,12 +169,14 @@ class _ActionChunker:
             or self.action_count == self.chunk_size
         ):
             ret = (self.bulk_data, self.bulk_actions)
-            self.bulk_actions, self.bulk_data = [], []
-            self.size, self.action_count = 0, 0
+            self.bulk_actions = []
+            self.bulk_data = []
+            self.size = 0
+            self.action_count = 0
 
-        self.bulk_actions.append(action)
-        if data is not None:
-            self.bulk_actions.append(data)
+        self.bulk_actions.append(action_bytes)
+        if data_bytes is not None:
+            self.bulk_actions.append(data_bytes)
             self.bulk_data.append((raw_action, raw_data))
         else:
             self.bulk_data.append((raw_action,))
@@ -139,15 +185,43 @@ class _ActionChunker:
         self.action_count += 1
         return ret
 
-    def flush(self):
+    def flush(
+        self,
+    ) -> Optional[
+        Tuple[
+            List[
+                Union[
+                    Tuple[_TYPE_BULK_ACTION_HEADER],
+                    Tuple[_TYPE_BULK_ACTION_HEADER, _TYPE_BULK_ACTION_BODY],
+                ]
+            ],
+            List[bytes],
+        ]
+    ]:
         ret = None
         if self.bulk_actions:
             ret = (self.bulk_data, self.bulk_actions)
-            self.bulk_actions, self.bulk_data = [], []
+            self.bulk_actions = []
+            self.bulk_data = []
         return ret
 
 
-def _chunk_actions(actions, chunk_size, max_chunk_bytes, serializer):
+def _chunk_actions(
+    actions: Iterable[_TYPE_BULK_ACTION_HEADER_AND_BODY],
+    chunk_size: int,
+    max_chunk_bytes: int,
+    serializer: Serializer,
+) -> Iterable[
+    Tuple[
+        List[
+            Union[
+                Tuple[_TYPE_BULK_ACTION_HEADER],
+                Tuple[_TYPE_BULK_ACTION_HEADER, _TYPE_BULK_ACTION_BODY],
+            ]
+        ],
+        List[bytes],
+    ]
+]:
     """
     Split actions into chunks by number or size, serialize them into strings in
     the process.
@@ -164,7 +238,17 @@ def _chunk_actions(actions, chunk_size, max_chunk_bytes, serializer):
         yield ret
 
 
-def _process_bulk_chunk_success(resp, bulk_data, raise_on_error=True):
+def _process_bulk_chunk_success(
+    resp: Dict[str, Any],
+    bulk_data: List[
+        Union[
+            Tuple[_TYPE_BULK_ACTION_HEADER],
+            Tuple[_TYPE_BULK_ACTION_HEADER, _TYPE_BULK_ACTION_BODY],
+        ]
+    ],
+    ignore_status: Collection[int],
+    raise_on_error: bool = True,
+) -> Iterator[Tuple[bool, Dict[str, Any]]]:
     # if raise on error is set, we need to collect errors per chunk before raising them
     errors = []
 
@@ -172,11 +256,13 @@ def _process_bulk_chunk_success(resp, bulk_data, raise_on_error=True):
     for data, (op_type, item) in zip(
         bulk_data, map(methodcaller("popitem"), resp["items"])
     ):
-        ok = 200 <= item.get("status", 500) < 300
-        if not ok and raise_on_error:
+        status_code = item.get("status", 500)
+
+        ok = 200 <= status_code < 300
+        if not ok and raise_on_error and status_code not in ignore_status:
             # include original document source
             if len(data) > 1:
-                item["data"] = data[1]
+                item["data"] = data[1]  # type: ignore[misc]
             errors.append({op_type: item})
 
         if ok or not errors:
@@ -185,14 +271,23 @@ def _process_bulk_chunk_success(resp, bulk_data, raise_on_error=True):
             yield ok, {op_type: item}
 
     if errors:
-        raise BulkIndexError("%i document(s) failed to index." % len(errors), errors)
+        raise BulkIndexError(f"{len(errors)} document(s) failed to index.", errors)
 
 
 def _process_bulk_chunk_error(
-    error, bulk_data, raise_on_exception=True, raise_on_error=True
-):
+    error: ApiError,
+    bulk_data: List[
+        Union[
+            Tuple[_TYPE_BULK_ACTION_HEADER],
+            Tuple[_TYPE_BULK_ACTION_HEADER, _TYPE_BULK_ACTION_BODY],
+        ]
+    ],
+    ignore_status: Collection[int],
+    raise_on_exception: bool = True,
+    raise_on_error: bool = True,
+) -> Iterable[Tuple[bool, Dict[str, Any]]]:
     # default behavior - just propagate exception
-    if raise_on_exception:
+    if raise_on_exception and error.status_code not in ignore_status:
         raise error
 
     # if we are not propagating, mark all actions in current chunk as failed
@@ -203,15 +298,15 @@ def _process_bulk_chunk_error(
         # collect all the information about failed actions
         op_type, action = data[0].copy().popitem()
         info = {"error": err_message, "status": error.status_code, "exception": error}
-        if op_type != "delete":
-            info["data"] = data[1]
+        if op_type != "delete" and len(data) > 1:
+            info["data"] = data[1]  # type: ignore[misc]
         info.update(action)
         exc_errors.append({op_type: info})
 
     # emulate standard behavior for failed actions
-    if raise_on_error:
+    if raise_on_error and error.status_code not in ignore_status:
         raise BulkIndexError(
-            "%i document(s) failed to index." % len(exc_errors), exc_errors
+            f"{len(exc_errors)} document(s) failed to index.", exc_errors
         )
     else:
         for err in exc_errors:
@@ -219,51 +314,65 @@ def _process_bulk_chunk_error(
 
 
 def _process_bulk_chunk(
-    client,
-    bulk_actions,
-    bulk_data,
-    raise_on_exception=True,
-    raise_on_error=True,
-    *args,
-    **kwargs
-):
+    client: Elasticsearch,
+    bulk_actions: List[bytes],
+    bulk_data: List[
+        Union[
+            Tuple[_TYPE_BULK_ACTION_HEADER],
+            Tuple[_TYPE_BULK_ACTION_HEADER, _TYPE_BULK_ACTION_BODY],
+        ]
+    ],
+    raise_on_exception: bool = True,
+    raise_on_error: bool = True,
+    ignore_status: Union[int, Collection[int]] = (),
+    *args: Any,
+    **kwargs: Any,
+) -> Iterable[Tuple[bool, Dict[str, Any]]]:
     """
     Send a bulk request to elasticsearch and process the output.
     """
+    if isinstance(ignore_status, int):
+        ignore_status = (ignore_status,)
+
     try:
         # send the actual request
-        resp = client.bulk("\n".join(bulk_actions) + "\n", *args, **kwargs)
-    except TransportError as e:
+        resp = client.bulk(*args, operations=bulk_actions, **kwargs)  # type: ignore[arg-type]
+    except ApiError as e:
         gen = _process_bulk_chunk_error(
             error=e,
             bulk_data=bulk_data,
+            ignore_status=ignore_status,
             raise_on_exception=raise_on_exception,
             raise_on_error=raise_on_error,
         )
     else:
         gen = _process_bulk_chunk_success(
-            resp=resp, bulk_data=bulk_data, raise_on_error=raise_on_error
+            resp=resp.body,
+            bulk_data=bulk_data,
+            ignore_status=ignore_status,
+            raise_on_error=raise_on_error,
         )
-    for item in gen:
-        yield item
+    yield from gen
 
 
 def streaming_bulk(
-    client,
-    actions,
-    chunk_size=500,
-    max_chunk_bytes=100 * 1024 * 1024,
-    raise_on_error=True,
-    expand_action_callback=expand_action,
-    raise_on_exception=True,
-    max_retries=0,
-    initial_backoff=2,
-    max_backoff=600,
-    yield_ok=True,
-    *args,
-    **kwargs
-):
-
+    client: Elasticsearch,
+    actions: Iterable[_TYPE_BULK_ACTION],
+    chunk_size: int = 500,
+    max_chunk_bytes: int = 100 * 1024 * 1024,
+    raise_on_error: bool = True,
+    expand_action_callback: Callable[
+        [_TYPE_BULK_ACTION], _TYPE_BULK_ACTION_HEADER_AND_BODY
+    ] = expand_action,
+    raise_on_exception: bool = True,
+    max_retries: int = 0,
+    initial_backoff: float = 2,
+    max_backoff: float = 600,
+    yield_ok: bool = True,
+    ignore_status: Union[int, Collection[int]] = (),
+    *args: Any,
+    **kwargs: Any,
+) -> Iterable[Tuple[bool, Dict[str, Any]]]:
     """
     Streaming bulk consumes actions from the iterable passed in and yields
     results per action. For non-streaming usecases use
@@ -295,15 +404,31 @@ def streaming_bulk(
         2**retry_number``
     :arg max_backoff: maximum number of seconds a retry will wait
     :arg yield_ok: if set to False will skip successful documents in the output
+    :arg ignore_status: list of HTTP status code that you want to ignore
     """
-    actions = map(expand_action_callback, actions)
+    client = client.options()
+    client._client_meta = (("h", "bp"),)
 
+    serializer = client.transport.serializers.get_serializer("application/json")
+
+    bulk_data: List[
+        Union[
+            Tuple[_TYPE_BULK_ACTION_HEADER],
+            Tuple[_TYPE_BULK_ACTION_HEADER, _TYPE_BULK_ACTION_BODY],
+        ]
+    ]
+    bulk_actions: List[bytes]
     for bulk_data, bulk_actions in _chunk_actions(
-        actions, chunk_size, max_chunk_bytes, client.transport.serializer
+        map(expand_action_callback, actions), chunk_size, max_chunk_bytes, serializer
     ):
-
         for attempt in range(max_retries + 1):
-            to_retry, to_retry_data = [], []
+            to_retry: List[bytes] = []
+            to_retry_data: List[
+                Union[
+                    Tuple[_TYPE_BULK_ACTION_HEADER],
+                    Tuple[_TYPE_BULK_ACTION_HEADER, _TYPE_BULK_ACTION_BODY],
+                ]
+            ] = []
             if attempt:
                 time.sleep(min(max_backoff, initial_backoff * 2 ** (attempt - 1)))
 
@@ -316,11 +441,11 @@ def streaming_bulk(
                         bulk_data,
                         raise_on_exception,
                         raise_on_error,
+                        ignore_status,
                         *args,
-                        **kwargs
+                        **kwargs,
                     ),
                 ):
-
                     if not ok:
                         action, info = info.popitem()
                         # retry if retries enabled, we get 429, and we are not
@@ -330,18 +455,16 @@ def streaming_bulk(
                             and info["status"] == 429
                             and (attempt + 1) <= max_retries
                         ):
-                            # _process_bulk_chunk expects strings so we need to
+                            # _process_bulk_chunk expects bytes so we need to
                             # re-serialize the data
-                            to_retry.extend(
-                                map(client.transport.serializer.dumps, data)
-                            )
+                            to_retry.extend(map(serializer.dumps, data))
                             to_retry_data.append(data)
                         else:
                             yield ok, {action: info}
                     elif yield_ok:
                         yield ok, info
 
-            except TransportError as e:
+            except ApiError as e:
                 # suppress 429 errors since we will retry them
                 if attempt == max_retries or e.status_code != 429:
                     raise
@@ -352,7 +475,14 @@ def streaming_bulk(
                 bulk_actions, bulk_data = to_retry, to_retry_data
 
 
-def bulk(client, actions, stats_only=False, *args, **kwargs):
+def bulk(
+    client: Elasticsearch,
+    actions: Iterable[_TYPE_BULK_ACTION],
+    stats_only: bool = False,
+    ignore_status: Union[int, Collection[int]] = (),
+    *args: Any,
+    **kwargs: Any,
+) -> Tuple[int, Union[int, List[Dict[str, Any]]]]:
     """
     Helper for the :meth:`~elasticsearch.Elasticsearch.bulk` api that provides
     a more human friendly interface - it consumes an iterator of actions and
@@ -374,6 +504,7 @@ def bulk(client, actions, stats_only=False, *args, **kwargs):
     :arg actions: iterator containing the actions
     :arg stats_only: if `True` only report number of successful/failed
         operations instead of just number of successful and a list of error responses
+    :arg ignore_status: list of HTTP status code that you want to ignore
 
     Any additional keyword arguments will be passed to
     :func:`~elasticsearch.helpers.streaming_bulk` which is used to execute
@@ -387,7 +518,9 @@ def bulk(client, actions, stats_only=False, *args, **kwargs):
 
     # make streaming_bulk yield successful results so we can count them
     kwargs["yield_ok"] = True
-    for ok, item in streaming_bulk(client, actions, *args, **kwargs):
+    for ok, item in streaming_bulk(
+        client, actions, ignore_status=ignore_status, *args, **kwargs  # type: ignore[misc]
+    ):
         # go through request-response pairs and detect failures
         if not ok:
             if not stats_only:
@@ -400,16 +533,19 @@ def bulk(client, actions, stats_only=False, *args, **kwargs):
 
 
 def parallel_bulk(
-    client,
-    actions,
-    thread_count=4,
-    chunk_size=500,
-    max_chunk_bytes=100 * 1024 * 1024,
-    queue_size=4,
-    expand_action_callback=expand_action,
-    *args,
-    **kwargs
-):
+    client: Elasticsearch,
+    actions: Iterable[_TYPE_BULK_ACTION],
+    thread_count: int = 4,
+    chunk_size: int = 500,
+    max_chunk_bytes: int = 100 * 1024 * 1024,
+    queue_size: int = 4,
+    expand_action_callback: Callable[
+        [_TYPE_BULK_ACTION], _TYPE_BULK_ACTION_HEADER_AND_BODY
+    ] = expand_action,
+    ignore_status: Union[int, Collection[int]] = (),
+    *args: Any,
+    **kwargs: Any,
+) -> Iterable[Tuple[bool, Any]]:
     """
     Parallel version of the bulk helper run in multiple threads at once.
 
@@ -427,19 +563,30 @@ def parallel_bulk(
         (`None` if data line should be omitted).
     :arg queue_size: size of the task queue between the main thread (producing
         chunks to send) and the processing threads.
+    :arg ignore_status: list of HTTP status code that you want to ignore
     """
     # Avoid importing multiprocessing unless parallel_bulk is used
     # to avoid exceptions on restricted environments like App Engine
     from multiprocessing.pool import ThreadPool
 
-    actions = map(expand_action_callback, actions)
+    expanded_actions = map(expand_action_callback, actions)
+    serializer = client.transport.serializers.get_serializer("application/json")
 
     class BlockingPool(ThreadPool):
-        def _setup_queues(self):
-            super(BlockingPool, self)._setup_queues()  # type: ignore
+        def _setup_queues(self) -> None:
+            super()._setup_queues()  # type: ignore
             # The queue must be at least the size of the number of threads to
             # prevent hanging when inserting sentinel values during teardown.
-            self._inqueue = Queue(max(queue_size, thread_count))
+            self._inqueue: Queue[
+                Tuple[
+                    List[
+                        Union[
+                            Tuple[Dict[str, Any]], Tuple[Dict[str, Any], Dict[str, Any]]
+                        ]
+                    ],
+                    List[bytes],
+                ]
+            ] = Queue(max(queue_size, thread_count))
             self._quick_put = self._inqueue.put
 
     pool = BlockingPool(thread_count)
@@ -448,15 +595,17 @@ def parallel_bulk(
         for result in pool.imap(
             lambda bulk_chunk: list(
                 _process_bulk_chunk(
-                    client, bulk_chunk[1], bulk_chunk[0], *args, **kwargs
+                    client,
+                    bulk_chunk[1],
+                    bulk_chunk[0],
+                    ignore_status=ignore_status,  # type: ignore[misc]
+                    *args,
+                    **kwargs,
                 )
             ),
-            _chunk_actions(
-                actions, chunk_size, max_chunk_bytes, client.transport.serializer
-            ),
+            _chunk_actions(expanded_actions, chunk_size, max_chunk_bytes, serializer),
         ):
-            for item in result:
-                yield item
+            yield from result
 
     finally:
         pool.close()
@@ -464,17 +613,17 @@ def parallel_bulk(
 
 
 def scan(
-    client,
-    query=None,
-    scroll="5m",
-    raise_on_error=True,
-    preserve_order=False,
-    size=1000,
-    request_timeout=None,
-    clear_scroll=True,
-    scroll_kwargs=None,
-    **kwargs
-):
+    client: Elasticsearch,
+    query: Optional[Any] = None,
+    scroll: str = "5m",
+    raise_on_error: bool = True,
+    preserve_order: bool = False,
+    size: int = 1000,
+    request_timeout: Optional[float] = None,
+    clear_scroll: bool = True,
+    scroll_kwargs: Optional[MutableMapping[str, Any]] = None,
+    **kwargs: Any,
+) -> Iterable[Dict[str, Any]]:
     """
     Simple abstraction on top of the
     :meth:`~elasticsearch.Elasticsearch.scroll` api - a simple iterator that
@@ -515,64 +664,109 @@ def scan(
 
     """
     scroll_kwargs = scroll_kwargs or {}
-
     if not preserve_order:
         query = query.copy() if query else {}
         query["sort"] = "_doc"
 
-    # initial search
-    resp = client.search(
-        body=query, scroll=scroll, size=size, request_timeout=request_timeout, **kwargs
+    def pop_transport_kwargs(kw: MutableMapping[str, Any]) -> Dict[str, Any]:
+        # Grab options that should be propagated to every
+        # API call within this helper instead of just 'search()'
+        transport_kwargs = {}
+        for key in ("headers", "api_key", "http_auth", "basic_auth", "bearer_auth"):
+            try:
+                value = kw.pop(key)
+                if key == "http_auth":
+                    key = "basic_auth"
+                transport_kwargs[key] = value
+            except KeyError:
+                pass
+        return transport_kwargs
+
+    client = client.options(
+        request_timeout=request_timeout, **pop_transport_kwargs(kwargs)
     )
+    client._client_meta = (("h", "s"),)
+
+    # Setting query={"from": ...} would make 'from' be used
+    # as a keyword argument instead of 'from_'. We handle that here.
+    def normalize_from_keyword(kw: MutableMapping[str, Any]) -> None:
+        if "from" in kw:
+            kw["from_"] = kw.pop("from")
+
+    normalize_from_keyword(kwargs)
+    try:
+        search_kwargs = query.copy() if query else {}
+        normalize_from_keyword(search_kwargs)
+        search_kwargs.update(kwargs)
+        search_kwargs["scroll"] = scroll
+        search_kwargs["size"] = size
+        resp = client.search(**search_kwargs)
+
+    # Try the old deprecated way if we fail immediately on parameters.
+    except TypeError:
+        search_kwargs = kwargs.copy()
+        search_kwargs["scroll"] = scroll
+        search_kwargs["size"] = size
+        resp = client.search(body=query, **search_kwargs)  # type: ignore[call-arg]
+
     scroll_id = resp.get("_scroll_id")
+    scroll_transport_kwargs = pop_transport_kwargs(scroll_kwargs)
+    if scroll_transport_kwargs:
+        scroll_client = client.options(**scroll_transport_kwargs)
+    else:
+        scroll_client = client
 
     try:
         while scroll_id and resp["hits"]["hits"]:
-            for hit in resp["hits"]["hits"]:
-                yield hit
+            yield from resp["hits"]["hits"]
+
+            # Default to 0 if the value isn't included in the response
+            shards_info: Dict[str, int] = resp["_shards"]
+            shards_successful = shards_info.get("successful", 0)
+            shards_skipped = shards_info.get("skipped", 0)
+            shards_total = shards_info.get("total", 0)
 
             # check if we have any errors
-            if (resp["_shards"]["successful"] + resp["_shards"]["skipped"]) < resp[
-                "_shards"
-            ]["total"]:
+            if (shards_successful + shards_skipped) < shards_total:
+                shards_message = "Scroll request has only succeeded on %d (+%d skipped) shards out of %d."
                 logger.warning(
-                    "Scroll request has only succeeded on %d (+%d skipped) shards out of %d.",
-                    resp["_shards"]["successful"],
-                    resp["_shards"]["skipped"],
-                    resp["_shards"]["total"],
+                    shards_message,
+                    shards_successful,
+                    shards_skipped,
+                    shards_total,
                 )
                 if raise_on_error:
                     raise ScanError(
                         scroll_id,
-                        "Scroll request has only succeeded on %d (+%d skipped) shards out of %d."
+                        shards_message
                         % (
-                            resp["_shards"]["successful"],
-                            resp["_shards"]["skipped"],
-                            resp["_shards"]["total"],
+                            shards_successful,
+                            shards_skipped,
+                            shards_total,
                         ),
                     )
-            resp = client.scroll(
-                body={"scroll_id": scroll_id, "scroll": scroll}, **scroll_kwargs
+            resp = scroll_client.scroll(
+                scroll_id=scroll_id, scroll=scroll, **scroll_kwargs
             )
             scroll_id = resp.get("_scroll_id")
 
     finally:
         if scroll_id and clear_scroll:
-            client.clear_scroll(body={"scroll_id": [scroll_id]}, ignore=(404,))
+            client.options(ignore_status=404).clear_scroll(scroll_id=scroll_id)
 
 
 def reindex(
-    client,
-    source_index,
-    target_index,
-    query=None,
-    target_client=None,
-    chunk_size=500,
-    scroll="5m",
-    scan_kwargs={},
-    bulk_kwargs={},
-):
-
+    client: Elasticsearch,
+    source_index: Union[str, Collection[str]],
+    target_index: str,
+    query: Optional[Any] = None,
+    target_client: Optional[Elasticsearch] = None,
+    chunk_size: int = 500,
+    scroll: str = "5m",
+    op_type: Optional[str] = None,
+    scan_kwargs: MutableMapping[str, Any] = {},
+    bulk_kwargs: MutableMapping[str, Any] = {},
+) -> Tuple[int, Union[int, List[Dict[str, Any]]]]:
     """
     Reindex all documents from one index that satisfy a given query
     to another, potentially (if `target_client` is specified) on a different cluster.
@@ -598,6 +792,9 @@ def reindex(
     :arg chunk_size: number of docs in one chunk sent to es (default: 500)
     :arg scroll: Specify how long a consistent view of the index should be
         maintained for scrolled search
+    :arg op_type: Explicit operation type. Defaults to '_index'. Data streams must
+        be set to 'create'. If not specified, will auto-detect if target_index is a
+        data stream.
     :arg scan_kwargs: additional kwargs to be passed to
         :func:`~elasticsearch.helpers.scan`
     :arg bulk_kwargs: additional kwargs to be passed to
@@ -606,18 +803,43 @@ def reindex(
     target_client = client if target_client is None else target_client
     docs = scan(client, query=query, index=source_index, scroll=scroll, **scan_kwargs)
 
-    def _change_doc_index(hits, index):
+    def _change_doc_index(
+        hits: Iterable[Dict[str, Any]], index: str, op_type: Optional[str]
+    ) -> Iterable[Dict[str, Any]]:
         for h in hits:
             h["_index"] = index
+            if op_type is not None:
+                h["_op_type"] = op_type
             if "fields" in h:
                 h.update(h.pop("fields"))
             yield h
 
     kwargs = {"stats_only": True}
     kwargs.update(bulk_kwargs)
+
+    is_data_stream = False
+    try:
+        # Verify if the target_index is data stream or index
+        data_streams = target_client.indices.get_data_stream(
+            name=target_index, expand_wildcards="all"
+        )
+        is_data_stream = any(
+            data_stream["name"] == target_index
+            for data_stream in data_streams["data_streams"]
+        )
+    except (TransportError, KeyError, NotFoundError):
+        # If its not data stream, might be index
+        pass
+
+    if is_data_stream:
+        if op_type not in (None, "create"):
+            raise ValueError("Data streams must have 'op_type' set to 'create'")
+        else:
+            op_type = "create"
+
     return bulk(
         target_client,
-        _change_doc_index(docs, target_index),
+        _change_doc_index(docs, target_index, op_type),
         chunk_size=chunk_size,
-        **kwargs
+        **kwargs,
     )
